@@ -70,6 +70,42 @@ GnomePropertyDescriptor FsUsageProperty_Descriptor = {
 
 static GList *widget_list = NULL;
 
+extern void gtop_show_mtbar (GtkWidget *w, gpointer gp);
+
+static GtkWidget *
+fsusage_menu_prepare ()
+{
+	GtkWidget *menu;
+	GtkWidget *mi;
+
+	menu = gtk_menu_new ();
+
+	mi = gtk_menu_item_new_with_label (_("Show menubar"));
+	gtk_signal_connect (GTK_OBJECT (mi), "activate",
+			    GTK_SIGNAL_FUNC (gtop_show_mtbar),
+			    (gpointer) FALSE);
+	gtk_menu_append (GTK_MENU (menu), mi);
+	gtk_widget_show (mi);
+
+	mi = gtk_menu_item_new_with_label (_("Show toolbar"));
+	gtk_signal_connect (GTK_OBJECT (mi), "activate",
+			    GTK_SIGNAL_FUNC (gtop_show_mtbar),
+			    (gpointer) TRUE);
+	gtk_menu_append (GTK_MENU (menu), mi);
+	gtk_widget_show (mi);
+
+	return menu;
+}
+
+static void
+fsusage_button_press (GtkCList *cl, GdkEventButton *e,
+		       GtkMenu *m)
+{
+	if (e->button == 3)
+		gtk_menu_popup (m, NULL, NULL, NULL,
+				NULL, e->button, e->time);
+}
+
 void
 fsusage_new (GTopFsUsageData *d, GtkWidget *widget, gint ftype)
 {
@@ -90,6 +126,9 @@ fsusage_new (GTopFsUsageData *d, GtkWidget *widget, gint ftype)
 
 	gtk_widget_show (d->graph);
 
+	gtk_signal_connect (GTK_OBJECT (d->sw), "button_press_event",
+			    fsusage_button_press, fsusage_menu_prepare ());
+
 	fsusage_type_set (d, ftype);
 
 	widget_list = g_list_append (widget_list, widget);
@@ -250,13 +289,15 @@ fsusage_update (GTopFsUsageData *d)
 	if (mount_list)
 		glibtop_free (mount_list);
 
+	memset (&mountlist, 0, sizeof (glibtop_mountlist));
+
 	mount_list = glibtop_get_mountlist (&mountlist, 0);
 
 	n = mountlist.number;
 
 	/* temporary info */
 
-	ti = g_new (FsUsageProcInfo, n);
+	ti = g_new0 (FsUsageProcInfo, n);
 
 	value = 0; /* keep gcc happy */
 	d->value_total = 0;
@@ -377,7 +418,7 @@ fsusage_update (GTopFsUsageData *d)
 	}
 
 	fsusage_number = n;
-	fsusage_data = g_new (FsUsageProcInfo, n+1);
+	fsusage_data = g_new0 (FsUsageProcInfo, n+1);
 
 	memset (fsusage_data, 0, sizeof (FsUsageProcInfo) * (n+1));
 	
@@ -487,7 +528,7 @@ fsusage_properties_init (GnomePropertyObject *object)
 	if (temp_properties->fsmode == GTOP_FSMODE_SUBLOCKS)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 
 	cb_data->button = button;
 	cb_data->object = object;
@@ -501,7 +542,7 @@ fsusage_properties_init (GnomePropertyObject *object)
 	if (temp_properties->fsmode == GTOP_FSMODE_BLOCKS)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 
 	cb_data->button = button;
 	cb_data->object = object;
@@ -515,7 +556,7 @@ fsusage_properties_init (GnomePropertyObject *object)
 	if (temp_properties->fsmode == GTOP_FSMODE_INODES)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 
 	cb_data->button = button;
 	cb_data->object = object;
@@ -549,7 +590,7 @@ fsusage_properties_init (GnomePropertyObject *object)
 			gtk_toggle_button_set_state
 				(GTK_TOGGLE_BUTTON (label), TRUE);
 
-		cb_data = g_new (RadioButtonCbData, 1);
+		cb_data = g_new0 (RadioButtonCbData, 1);
 
 		cb_data->index = i;
 		cb_data->button = label;
