@@ -44,7 +44,7 @@ guint		gtop_fsusage_get_type	(void);
 
 extern GnomeMDI *mdi;
 
-extern gchar *gtop_fsusage_type_labels[];
+extern GnomeUIInfo gtop_fsusage_radio_items [];
 
 END_GNOME_DECLS
 
