@@ -40,11 +40,9 @@ struct _GTopSummaryData
 
 GTopStatusBarData *gtop_statusbar_new (void);
 void gtop_statusbar_update (GTopStatusBarData *);
-void gtop_statusbar_destroy (GTopStatusBarData *);
 
 GTopSummaryData *gtop_summary_new (void);
 void gtop_summary_map (GTopSummaryData *);
 void gtop_summary_unmap (GTopSummaryData *);
-void gtop_summary_destroy (GTopSummaryData *);
         
 #endif
